import mitt from 'mitt';
import { chatExtension } from '../extension';
import useGetRoomEngine from '../hooks/useRoomEngine';
export const roomEngine = useGetRoomEngine();

export enum EventType {
  VISIBLE_CHANGE = 'RoomVisibleChange',
  ROOM_DESTROY = 'RoomDestroy',
}

export class RoomService {
  static instance?: RoomService;
  public TUIRoomKitMethods: any;
  private emitter = mitt();

  static getInstance(): RoomService {
    if (!RoomService.instance) {
      RoomService.instance = new RoomService();
    }
    return RoomService.instance;
  }
  static destroyInstance(): void {
    if (!RoomService.instance) return;
    RoomService.instance = undefined;
  }

  public init(TUIRoomKitMethods: any) {
    this.initRoomKitMethods(TUIRoomKitMethods);
    chatExtension.init();
  }
  public initRoomKitMethods(TUIRoomKitMethods: any) {
    this.TUIRoomKitMethods = TUIRoomKitMethods;
  }

  on(eventType: EventType, callback: (data?: any) => any) {
    this.emitter.on(eventType, callback);
  }
  off(eventType: EventType, callback: (data?: any) => void) {
    this.emitter.off(eventType, callback);
  }
  emit(eventType: EventType, data?: any) {
    this.emitter.emit(eventType, data);
  }
}


export const roomService = RoomService.getInstance();
